package SimpleTestPlugin;
use exact;

sub init {}

1;
